aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/main/java/com/google/devtools/build/lib/actions/ActionOwner.java
diff options
context:
space:
mode:
authorGravatar shahan <shahan@google.com>2018-03-10 05:14:09 -0800
committerGravatar Copybara-Service <copybara-piper@google.com>2018-03-10 05:15:51 -0800
commit50f99d56bb710f01524bd3f04882dada16a792c3 (patch)
tree09e3902e29ebf3a8a7d41db5af4d310989fbe591 /src/main/java/com/google/devtools/build/lib/actions/ActionOwner.java
parentdeccc485603c004daad959fd747f1c0c9efc4f00 (diff)
ActionOwner references only BuildEvent instead of full BuildConfiguration
This reduces the size of its serialized representation. PiperOrigin-RevId: 188597127
Diffstat (limited to 'src/main/java/com/google/devtools/build/lib/actions/ActionOwner.java')
-rw-r--r--src/main/java/com/google/devtools/build/lib/actions/ActionOwner.java8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/main/java/com/google/devtools/build/lib/actions/ActionOwner.java b/src/main/java/com/google/devtools/build/lib/actions/ActionOwner.java
index 77c67a8121..eaad2df80b 100644
--- a/src/main/java/com/google/devtools/build/lib/actions/ActionOwner.java
+++ b/src/main/java/com/google/devtools/build/lib/actions/ActionOwner.java
@@ -56,7 +56,7 @@ public abstract class ActionOwner {
@Nullable String mnemonic,
@Nullable String targetKind,
String configurationChecksum,
- @Nullable BuildConfigurationInterface configuration,
+ @Nullable BuildConfigurationEvent configuration,
@Nullable String additionalProgressInfo,
@Nullable PlatformInfo executionPlatform) {
return new AutoValue_ActionOwner(
@@ -94,11 +94,11 @@ public abstract class ActionOwner {
public abstract String getConfigurationChecksum();
/**
* Return the configuration of the action owner, if any, as it should be reported in the build
* event protocol.
*/
@Nullable
- public abstract BuildConfigurationInterface getConfiguration();
+ public abstract BuildConfigurationEvent getConfiguration();
/** Returns the target kind (rule class name) for this ActionOwner, if any; null otherwise. */
@Nullable
@@ -94,11 +94,11 @@ public abstract class ActionOwner {
public abstract String getConfigurationChecksum();
/**
- * Return the configuration of the action owner, if any, as it should be reported in the build
- * event protocol.
+ * Return the {@link BuildConfigurationEvent} associated with the action owner, if any, as it
+ * should be reported in the build event protocol.
*/